; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
;[Command]
;name = "QCF2_a"
;command = ~D, DF, F, D, DF, F, a
;time = 30

;[Command]
;name = "QCF2_b"
;command = ~D, DF, F, D, DF, F, b
;time = 30

;[Command]
;name = "QCF2_c"
;command = ~D, DF, F, D, DF, F, c
;time = 30

;[Command]
;name = "QCF2_x"
;command = ~D, DF, F, D, DF, F, x
;time = 30

;[Command]
;name = "QCF2_y"
;command = ~D, DF, F, D, DF, F, y
;time = 30

;[Command]
;name = "QCF2_z"
;command = ~D, DF, F, D, DF, F, z
;time = 30

;[Command]
;name = "QCB2_a"
;command = ~D, DB, B, D, DB, B, a
;time = 30

;[Command]
;name = "QCB2_b"
;command = ~D, DB, B, D, DB, B, b
;time = 30

;[Command]
;name = "QCB2_c"
;command = ~D, DB, B, D, DB, B, c
;time = 30

;[Command]
;name = "QCB2_x"
;command = ~D, DB, B, D, DB, B, x
;time = 30

;[Command]
;name = "QCB2_y"
;command = ~D, DB, B, D, DB, B, y
;time = 30

;[Command]
;name = "QCB2_z"
;command = ~D, DB, B, D, DB, B, z
;time = 30

;[Command]
;name = "QCBHCF_z"
;command = ~D, DB, B, D, DF F, z
;time = 40


;-| Special Motions |------------------------------------------------------
;[Command]
;name = "QCF_a"
;command = ~D, DF, F, a

;[Command]
;name = "QCF_b"
;command = ~D, DF, F, b

;[Command]
;name = "QCF_c"
;command = ~D, DF, F, c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

;[Command]
;name = "QCB_c"
;command = ~D, DB, B, c

;[Command]
;name = "QCF_x"
;command = ~D, DF, F, x

;[Command]
;name = "QCF_y"
;command = ~D, DF, F, y

;[Command]
;name = "QCF_z"
;command = ~D, DF, F, z

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

;[Command]
;name = "QCB_z"
;command = ~D, DB, B, z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10
;---------------------------------------------------------------------------
;[Command]
;name = "BF_a"
;command = $B, F, a

;[Command]
;name = "BF_b"
;command = $B, F, b

;[Command]
;name = "BF_c"
;command = $B, F, c

[Command]
name = "FB_x"
command = $F, B, x

[Command]
name = "BF_a"
command = $F, B, a

[Command]
name = "BF_x"
command = $F, B, x

[Command]
name = "BB_a"
command = $B, B, a

[Command] 
name = "FF_a"
command = $F, F, a

[Command]
name = "FriendshipA"
command = $F, B, b

[Command]
name = "FriendshipB"
command = $F, B, y

[Command]
name = "BabalityA"
command = $B,B, b

[Command]
name = "BabalityB"
command = $B,B, y
;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "ax"
command = a+x
time = 1

[Command]
name = "by"
command = b+y
time = 1

;[Command]
;name = "yz"
;command = y+z
;time = 1

;[Command]
;name = "xyz"
;command = x+y+z
;time = 1

;[Command]
;name = "abc"
;command = a+b+c
;time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "bck_x"
command = /B,x
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "downfwd_a"
command = /DF,a
time = 1

[Command]
name = "downfwd_b"
command = /DF,b
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s ;	Start!
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
[State -1]
type = Changestate
value = 1100
triggerall = command = "ax"
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = stateno = [200, 500]
trigger2 = movecontact = 1
trigger3 = stateno = 1040
trigger3 = Pos Y = 0
trigger3 = movecontact = 1
;===========================================================================
[State -1]
type = Changestate
value = 1120
triggerall = command = "by"
trigger1 = ctrl = 1
trigger1 = statetype = S
;===========================================================================
[State -1]
type = Changestate
value = 1000
triggerall = command = "BB_a"
trigger1 = ctrl = 1
trigger1 = statetype = S
triggerall = p2stateno != 2020
triggerall = p2stateno != 2021
triggerall = p2stateno != 1020
triggerall = p2stateno != 1021
trigger2 = Pos Y = [-25, 0]
trigger2 = movecontact = 1
trigger3 = stateno = 1040
trigger3 = Pos Y = 0
trigger3 = movecontact = 1
;===========================================================================
[State -1]
type = Changestate
value = 2000
triggerall = command = "FF_a"
trigger1 = ctrl = 1
trigger1 = statetype = S
triggerall = p2stateno != 2020
triggerall = p2stateno != 2021
triggerall = p2stateno != 1020
triggerall = p2stateno != 1021
trigger2 = stateno = 1040
trigger2 = Pos Y = 0
trigger2 = movecontact = 1
;===========================================================================
[State -1]
type = Changestate
value = 1040
trigger1 = command = "QCB_x"
trigger1 = ctrl = 1
;--------------------------------------------------------------------
[State -1]
type = Changestate
value = 1070
trigger1 = command = "QCB_b"
trigger1 = ctrl = 1
trigger1 = statetype = S
;--------------------------------------------------------------------
[State -1];ROLENTO'S MEANER BROTHER
type = Changestate
value = 9100
trigger1 = command = "BF_a"
trigger2 = command = "z"
triggerall = ctrl = 1
triggerall = p2stateno = 9010
triggerall = p2life < 2
triggerall = P2statetype = S
triggerall = Statetype = S
triggerall = p2BodyDist X > 150
;--------------------------------------------------------------------
[State -1];DOUBLE CUT
type = Changestate
value = 9300
trigger1 = command = "FB_x"
trigger2 = command = "z"
triggerall = ctrl = 1
triggerall = p2stateno = 9010
triggerall = p2life < 2
triggerall = P2statetype = S
triggerall = Statetype = S
triggerall = p2BodyDist X > 10
triggerall = p2BodyDist X < 50
;--------------------------------------------------------------------
[State -1]; TOASTY
type = Changestate
value = 9149
trigger1 = command = "BF_x"
trigger2 = command = "c"
triggerall = ctrl = 1
triggerall = p2stateno = 9010
triggerall = P2statetype = S
triggerall = Statetype = S
triggerall = p2bodyDist X > 40
triggerall = p2bodyDist X < 90
;--------------------------------------------------------------------
[State -1]; ????
type = Changestate
value = 9400
trigger1 = command = "c"
triggerall = ctrl = 1
triggerall = p2stateno = 9010
triggerall = P2statetype = S
triggerall = Statetype = S
triggerall = p2bodyDist X > 0
triggerall = p2bodyDist X < 40
;--------------------------------------------------------------------
[State -1]; FRIENDSHIP
type = Changestate
value = 8000
trigger1 = command = "FriendshipA"
trigger1 = ctrl = 1
trigger1 = Var(19) = 0
trigger1 = p2stateno = 9010
trigger1 = statetype = S
trigger1 = P2statetype = S
;--------------------------------------------------------------------
[State -1]; FRIENDSHIP
type = Changestate
value = 8050
trigger1 = command = "FriendshipB"
trigger1 = ctrl = 1
trigger1 = p2stateno = 9010
trigger1 = Var(19) = 0
trigger1 = statetype = S
trigger1 = P2statetype = S
;--------------------------------------------------------------------
[State -1]; Babality
type = Changestate
value = 8100
trigger1 = command = "BabalityA"
triggerall = ctrl = 1
triggerall = Var(19) = 0
triggerall = p2stateno = 9010
triggerall = statetype = S
triggerall = P2statetype = S
trigger2 = command = "BabalityB"
;--------------------------------------------------------------------
[State -1]
type = Changestate
value = 170
triggerall = command = "start"
triggerall = ctrl = 1
trigger1 = statetype = S
trigger2 = statetype = C
;---------------------------------------------------------------------------
;Throw
[State -1]
type = Changestate
value = 800
trigger1 = command = "fwd_a"
trigger2 = command = "back_a"
triggerall = P2bodydist X < 10
triggerall = P2statetype != A
triggerall = ctrl = 1
triggerall = statetype = S
;------------------------------------------------------------------------
;Air Throw
[State -1]
type = Changestate
value = 800
trigger1 = command = "start"
trigger2 = command = "fwd_a"
trigger3 = command = "back_a"
triggerall = P2bodyDist X < 45
triggerall = P2bodyDist Y = [-60, 0]
triggerall = P2statetype = A
triggerall = ctrl = 1
triggerall = statetype = A
;------------------------------------------------------------------------
;Forearm
[State -1]
type = Changestate
value = 230
triggerall = command != "holddown"
triggerall = P2bodyDist X < 45
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "bck_x"
trigger2 = command = "fwd_x"
;---------------------------------------------------------------------------
;Roundhouse
[State -1]
type = Changestate
value = 240
triggerall = command = "y"
triggerall = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Sweep
[State -1]
type = Changestate
value = 245
trigger1 = command = "b"
trigger1 = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Knee
[State -1]
type = Changestate
value = 235
triggerall = command != "holddown"
triggerall = P2bodyDist X < 30
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "y"
trigger2 = command = "b"
;---------------------------------------------------------------------------
;High Left
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = S
trigger2 = stateno = 201
trigger2 = animelem = 5
trigger3 = statetype = S
trigger3 = stateno = 221
trigger3 = animelem = 5
trigger4 = statetype = S
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = statetype = S
trigger5 = stateno = 221
trigger5 = movecontact = 1
;--------------------------------------------------------------------------
;High Right
[State -1]
type = ChangeState
value = 201
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = stateno = 200
trigger1 = movecontact = 1
trigger2 = statetype = S
trigger2 = stateno = 220
trigger2 = movecontact = 1
trigger3 = statetype = S
trigger3 = stateno = 200
trigger3 = animelem = 3
trigger4 = statetype = S
trigger4 = stateno = 220
trigger4 = animelem = 3
;---------------------------------------------------------------------------
;High Kick
[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Low Left
[State -1]
type = ChangeState
value = 220
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = S
trigger2 = stateno = 221
trigger2 = movecontact = 1
trigger3 = statetype = S
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = statetype = S
trigger4 = stateno = 201
trigger4 = animtime = 0
trigger5 = statetype = S
trigger5 = stateno = 221
trigger5 = animtime = 0
;--------------------------------------------------------------------------
;Low Right
[State -1]
type = ChangeState
value = 221
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = stateno = 200
trigger1 = movecontact = 1
trigger2 = statetype = S
trigger2 = stateno = 220
trigger2 = movecontact = 1
trigger3 = statetype = S
trigger3 = stateno = 200
trigger3 = animtime = 0
trigger4 = statetype = S
trigger4 = stateno = 220
trigger4 = animtime = 0
;---------------------------------------------------------------------------
;Low Mid Kick
[State -1]
type = ChangeState
value = 225
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;------------------------------------------------------------------------
;Low Kick
[State -1]
type = ChangeState
value = 400
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;----------------------------------------------------------------------------
;Low High Kick
[State -1]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Low Punch
[State -1]
type = ChangeState
value = 420
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Uppercut
[State -1]
type = ChangeState
value = 430
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump Side kick
[State -1]
type = ChangeState
value = 620
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = anim != 41 
trigger1 = command = "y"
trigger2 = command = "b"
;---------------------------------------------------------------------
;Jump Kick
[State -1]
type = ChangeState
value = 600
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = anim = 41
trigger1 = command = "y"
trigger2 = command = "b"
;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 610
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = "a"
trigger2 = command = "x"
;---------------------------------------------------------------------
